@@ -33,8 +33,11 @@ def upload_component(path, name, service, convert, help_link, source_url):
     click.echo("Initialize component store. service:[{0}] api_base [{1}]".format(service, apibase))
     store = ComponentStore(service, apibase)
     try:
-        store.create_component(spec, name, help_link=help_link, source_url=source_url)
-        click.echo("Create component successfully")
-    except kaistack.clients.openapi_clients.pipelinecomponents.exceptions.ApiException:
-        store.update_component(spec, name, help_link=help_link, source_url=source_url)
-        click.echo("Update component successfully")
+        try:
+            store.create_component(spec, name, help_link=help_link, source_url=source_url)
+            click.echo("Create component successfully")
+        except kaistack.clients.openapi_clients.pipelinecomponents.exceptions.ApiException:
+            store.update_component(spec, name, help_link=help_link, source_url=source_url)
+            click.echo("Update component successfully")
+    except kaistack.clients.openapi_clients.pipelinecomponents.exceptions.ApiException as e:
+        click.echo("{0}".format(e))
