@@ -4,7 +4,7 @@ import unittest
 from kfp import dsl
 
 from kaistack.components.kubeflow_converter import component_to_template, containerOp_to_template
-
+from kfp.dsl._pipeline_param import PipelineParam
 COMPONENT_SPEC_FILENAME = os.path.join(os.path.dirname(__file__), 'kfp_component.yaml')
 
 
@@ -22,11 +22,11 @@ class KubeflowConverterTest(unittest.TestCase):
             name='echo',
             image='library/bash:4.4.23',
             command=['sh', '-c'],
-            arguments=['echo "hello world"']
+            arguments=['echo "hello world"', '%s' % PipelineParam(name="arg1")],
         )
 
         template = containerOp_to_template(echo_task)
         self.assertEqual('echo', template['name'])
         self.assertEqual('library/bash:4.4.23', template['container']['image'])
         self.assertEqual(['sh', '-c'], template['container']['command'])
-        self.assertEqual(['echo "hello world"'], template['container']['args'])
+        self.assertEqual(['echo "hello world"','{{inputs.parameters.arg1}}'], template['container']['args'])
